# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AgentPoolUpdateArgs', 'AgentPoolUpdate']

@pulumi.input_type
class AgentPoolUpdateArgs:
    def __init__(__self__, *,
                 pool_id: pulumi.Input[_builtins.str],
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AgentPoolUpdate resource.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input['AgentPoolUpdateScheduleArgs'] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        pulumi.set(__self__, "pool_id", pool_id)
        if agent_type is not None:
            pulumi.set(__self__, "agent_type", agent_type)
        if agents is not None:
            pulumi.set(__self__, "agents", agents)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notify_admins is not None:
            pulumi.set(__self__, "notify_admins", notify_admins)
        if notify_on_completion is not None:
            pulumi.set(__self__, "notify_on_completion", notify_on_completion)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if sort_order is not None:
            pulumi.set(__self__, "sort_order", sort_order)
        if target_version is not None:
            pulumi.set(__self__, "target_version", target_version)

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the agent pool to update.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pool_id", value)

    @_builtins.property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        """
        return pulumi.get(self, "agent_type")

    @agent_type.setter
    def agent_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_type", value)

    @_builtins.property
    @pulumi.getter
    def agents(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]:
        """
        The agents associated with the agent pool update.
        """
        return pulumi.get(self, "agents")

    @agents.setter
    def agents(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]):
        pulumi.set(self, "agents", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the agent pool update.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether auto-update is enabled for the agent pool.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the agent pool update.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notifyAdmins")
    def notify_admins(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to notify admins about the update.
        """
        return pulumi.get(self, "notify_admins")

    @notify_admins.setter
    def notify_admins(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_admins", value)

    @_builtins.property
    @pulumi.getter(name="notifyOnCompletion")
    def notify_on_completion(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to send notifications when the update completes.
        """
        return pulumi.get(self, "notify_on_completion")

    @notify_on_completion.setter
    def notify_on_completion(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_on_completion", value)

    @_builtins.property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reason for the update.
        """
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reason", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]:
        """
        The schedule configuration for the agent pool update.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the sort order.
        """
        return pulumi.get(self, "sort_order")

    @sort_order.setter
    def sort_order(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sort_order", value)

    @_builtins.property
    @pulumi.getter(name="targetVersion")
    def target_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The agent version to update to.
        """
        return pulumi.get(self, "target_version")

    @target_version.setter
    def target_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_version", value)


@pulumi.input_type
class _AgentPoolUpdateState:
    def __init__(__self__, *,
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AgentPoolUpdate resources.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input['AgentPoolUpdateScheduleArgs'] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] status: The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        if agent_type is not None:
            pulumi.set(__self__, "agent_type", agent_type)
        if agents is not None:
            pulumi.set(__self__, "agents", agents)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notify_admins is not None:
            pulumi.set(__self__, "notify_admins", notify_admins)
        if notify_on_completion is not None:
            pulumi.set(__self__, "notify_on_completion", notify_on_completion)
        if pool_id is not None:
            pulumi.set(__self__, "pool_id", pool_id)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if sort_order is not None:
            pulumi.set(__self__, "sort_order", sort_order)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target_version is not None:
            pulumi.set(__self__, "target_version", target_version)

    @_builtins.property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        """
        return pulumi.get(self, "agent_type")

    @agent_type.setter
    def agent_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_type", value)

    @_builtins.property
    @pulumi.getter
    def agents(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]:
        """
        The agents associated with the agent pool update.
        """
        return pulumi.get(self, "agents")

    @agents.setter
    def agents(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPoolUpdateAgentArgs']]]]):
        pulumi.set(self, "agents", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the agent pool update.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether auto-update is enabled for the agent pool.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the agent pool update.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notifyAdmins")
    def notify_admins(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to notify admins about the update.
        """
        return pulumi.get(self, "notify_admins")

    @notify_admins.setter
    def notify_admins(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_admins", value)

    @_builtins.property
    @pulumi.getter(name="notifyOnCompletion")
    def notify_on_completion(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to send notifications when the update completes.
        """
        return pulumi.get(self, "notify_on_completion")

    @notify_on_completion.setter
    def notify_on_completion(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "notify_on_completion", value)

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the agent pool to update.
        """
        return pulumi.get(self, "pool_id")

    @pool_id.setter
    def pool_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pool_id", value)

    @_builtins.property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reason for the update.
        """
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reason", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]:
        """
        The schedule configuration for the agent pool update.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AgentPoolUpdateScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the sort order.
        """
        return pulumi.get(self, "sort_order")

    @sort_order.setter
    def sort_order(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sort_order", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="targetVersion")
    def target_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The agent version to update to.
        """
        return pulumi.get(self, "target_version")

    @target_version.setter
    def target_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_version", value)


@pulumi.type_token("okta:index/agentPoolUpdate:AgentPoolUpdate")
class AgentPoolUpdate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']]] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages an Okta Agent Pool Update. Agent pool updates allow you to schedule and manage updates for agent pools.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AgentPoolUpdate("example",
            name="scheduled_update",
            agent_type="AD",
            notify_admins=True,
            pool_id="0oaspf3cfatE1nDO31d7",
            agents=[{
                "id": "a53slzqkptH2xEJ1r1d7",
                "pool_id": "0oaspf3cfatE1nDO31d7",
            }],
            schedule={
                "cron": "0 3 * * MON",
                "timezone": "America/Los_Angeles",
                "delay": 0,
                "duration": 1020,
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/agentPoolUpdate:AgentPoolUpdate example <pool_id>/<update_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AgentPoolUpdateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Okta Agent Pool Update. Agent pool updates allow you to schedule and manage updates for agent pools.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AgentPoolUpdate("example",
            name="scheduled_update",
            agent_type="AD",
            notify_admins=True,
            pool_id="0oaspf3cfatE1nDO31d7",
            agents=[{
                "id": "a53slzqkptH2xEJ1r1d7",
                "pool_id": "0oaspf3cfatE1nDO31d7",
            }],
            schedule={
                "cron": "0 3 * * MON",
                "timezone": "America/Los_Angeles",
                "delay": 0,
                "duration": 1020,
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/agentPoolUpdate:AgentPoolUpdate example <pool_id>/<update_id>
        ```

        :param str resource_name: The name of the resource.
        :param AgentPoolUpdateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AgentPoolUpdateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_type: Optional[pulumi.Input[_builtins.str]] = None,
                 agents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
                 notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']]] = None,
                 sort_order: Optional[pulumi.Input[_builtins.int]] = None,
                 target_version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AgentPoolUpdateArgs.__new__(AgentPoolUpdateArgs)

            __props__.__dict__["agent_type"] = agent_type
            __props__.__dict__["agents"] = agents
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["notify_admins"] = notify_admins
            __props__.__dict__["notify_on_completion"] = notify_on_completion
            if pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'pool_id'")
            __props__.__dict__["pool_id"] = pool_id
            __props__.__dict__["reason"] = reason
            __props__.__dict__["schedule"] = schedule
            __props__.__dict__["sort_order"] = sort_order
            __props__.__dict__["target_version"] = target_version
            __props__.__dict__["status"] = None
        super(AgentPoolUpdate, __self__).__init__(
            'okta:index/agentPoolUpdate:AgentPoolUpdate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agent_type: Optional[pulumi.Input[_builtins.str]] = None,
            agents: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notify_admins: Optional[pulumi.Input[_builtins.bool]] = None,
            notify_on_completion: Optional[pulumi.Input[_builtins.bool]] = None,
            pool_id: Optional[pulumi.Input[_builtins.str]] = None,
            reason: Optional[pulumi.Input[_builtins.str]] = None,
            schedule: Optional[pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']]] = None,
            sort_order: Optional[pulumi.Input[_builtins.int]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            target_version: Optional[pulumi.Input[_builtins.str]] = None) -> 'AgentPoolUpdate':
        """
        Get an existing AgentPoolUpdate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_type: Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        :param pulumi.Input[Sequence[pulumi.Input[Union['AgentPoolUpdateAgentArgs', 'AgentPoolUpdateAgentArgsDict']]]] agents: The agents associated with the agent pool update.
        :param pulumi.Input[_builtins.str] description: The description of the agent pool update.
        :param pulumi.Input[_builtins.bool] enabled: Whether auto-update is enabled for the agent pool.
        :param pulumi.Input[_builtins.str] name: The name of the agent pool update.
        :param pulumi.Input[_builtins.bool] notify_admins: Whether to notify admins about the update.
        :param pulumi.Input[_builtins.bool] notify_on_completion: Whether to send notifications when the update completes.
        :param pulumi.Input[_builtins.str] pool_id: The unique identifier of the agent pool to update.
        :param pulumi.Input[_builtins.str] reason: Reason for the update.
        :param pulumi.Input[Union['AgentPoolUpdateScheduleArgs', 'AgentPoolUpdateScheduleArgsDict']] schedule: The schedule configuration for the agent pool update.
        :param pulumi.Input[_builtins.int] sort_order: Specifies the sort order.
        :param pulumi.Input[_builtins.str] status: The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        :param pulumi.Input[_builtins.str] target_version: The agent version to update to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AgentPoolUpdateState.__new__(_AgentPoolUpdateState)

        __props__.__dict__["agent_type"] = agent_type
        __props__.__dict__["agents"] = agents
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["notify_admins"] = notify_admins
        __props__.__dict__["notify_on_completion"] = notify_on_completion
        __props__.__dict__["pool_id"] = pool_id
        __props__.__dict__["reason"] = reason
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["sort_order"] = sort_order
        __props__.__dict__["status"] = status
        __props__.__dict__["target_version"] = target_version
        return AgentPoolUpdate(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Agent types that are being monitored (e.g., AD, IWA, LDAP, MFA, OPP, RUM, Radius).
        """
        return pulumi.get(self, "agent_type")

    @_builtins.property
    @pulumi.getter
    def agents(self) -> pulumi.Output[Optional[Sequence['outputs.AgentPoolUpdateAgent']]]:
        """
        The agents associated with the agent pool update.
        """
        return pulumi.get(self, "agents")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the agent pool update.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether auto-update is enabled for the agent pool.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the agent pool update.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notifyAdmins")
    def notify_admins(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to notify admins about the update.
        """
        return pulumi.get(self, "notify_admins")

    @_builtins.property
    @pulumi.getter(name="notifyOnCompletion")
    def notify_on_completion(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to send notifications when the update completes.
        """
        return pulumi.get(self, "notify_on_completion")

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the agent pool to update.
        """
        return pulumi.get(self, "pool_id")

    @_builtins.property
    @pulumi.getter
    def reason(self) -> pulumi.Output[_builtins.str]:
        """
        Reason for the update.
        """
        return pulumi.get(self, "reason")

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> pulumi.Output[Optional['outputs.AgentPoolUpdateSchedule']]:
        """
        The schedule configuration for the agent pool update.
        """
        return pulumi.get(self, "schedule")

    @_builtins.property
    @pulumi.getter(name="sortOrder")
    def sort_order(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies the sort order.
        """
        return pulumi.get(self, "sort_order")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the agent pool update (e.g., Scheduled, InProgress, Completed, Failed).
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetVersion")
    def target_version(self) -> pulumi.Output[_builtins.str]:
        """
        The agent version to update to.
        """
        return pulumi.get(self, "target_version")

