# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetUiSchemaResult',
    'AwaitableGetUiSchemaResult',
    'get_ui_schema',
    'get_ui_schema_output',
]

@pulumi.output_type
class GetUiSchemaResult:
    """
    A collection of values returned by getUiSchema.
    """
    def __init__(__self__, created=None, id=None, last_updated=None, ui_schema=None):
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if ui_schema and not isinstance(ui_schema, dict):
            raise TypeError("Expected argument 'ui_schema' to be a dict")
        pulumi.set(__self__, "ui_schema", ui_schema)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        Timestamp when the UI Schema was created. (ISO 86001).
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID property of an UI Schema.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        Timestamp when the UI Schema was last modified (ISO 86001).
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> Optional['outputs.GetUiSchemaUiSchemaResult']:
        """
        - (Object) Representation of a resource.
        """
        return pulumi.get(self, "ui_schema")


class AwaitableGetUiSchemaResult(GetUiSchemaResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUiSchemaResult(
            created=self.created,
            id=self.id,
            last_updated=self.last_updated,
            ui_schema=self.ui_schema)


def get_ui_schema(id: Optional[_builtins.str] = None,
                  ui_schema: Optional[Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict']] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUiSchemaResult:
    """
    Use this data source to retrieve information about an Okta UI Schema.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_ui_schema(id="ui_schema_id")
    ```


    :param _builtins.str id: The ID property of an UI Schema.
    :param Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict'] ui_schema: - (Object) Representation of a resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['uiSchema'] = ui_schema
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getUiSchema:getUiSchema', __args__, opts=opts, typ=GetUiSchemaResult).value

    return AwaitableGetUiSchemaResult(
        created=pulumi.get(__ret__, 'created'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        ui_schema=pulumi.get(__ret__, 'ui_schema'))
def get_ui_schema_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                         ui_schema: Optional[pulumi.Input[Optional[Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict']]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUiSchemaResult]:
    """
    Use this data source to retrieve information about an Okta UI Schema.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_ui_schema(id="ui_schema_id")
    ```


    :param _builtins.str id: The ID property of an UI Schema.
    :param Union['GetUiSchemaUiSchemaArgs', 'GetUiSchemaUiSchemaArgsDict'] ui_schema: - (Object) Representation of a resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['uiSchema'] = ui_schema
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getUiSchema:getUiSchema', __args__, opts=opts, typ=GetUiSchemaResult)
    return __ret__.apply(lambda __response__: GetUiSchemaResult(
        created=pulumi.get(__response__, 'created'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        ui_schema=pulumi.get(__response__, 'ui_schema')))
