# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSecurityEventsProviderResult',
    'AwaitableGetSecurityEventsProviderResult',
    'get_security_events_provider',
    'get_security_events_provider_output',
]

@pulumi.output_type
class GetSecurityEventsProviderResult:
    """
    A collection of values returned by getSecurityEventsProvider.
    """
    def __init__(__self__, id=None, is_enabled=None, name=None, settings=None, status=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_enabled and not isinstance(is_enabled, str):
            raise TypeError("Expected argument 'is_enabled' to be a str")
        pulumi.set(__self__, "is_enabled", is_enabled)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if settings and not isinstance(settings, dict):
            raise TypeError("Expected argument 'settings' to be a dict")
        pulumi.set(__self__, "settings", settings)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of this instance.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> _builtins.str:
        """
        Whether or not the Security Events Provider is enabled.
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional['outputs.GetSecurityEventsProviderSettingsResult']:
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Indicates whether the Security Events Provider is active or not.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")


class AwaitableGetSecurityEventsProviderResult(GetSecurityEventsProviderResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityEventsProviderResult(
            id=self.id,
            is_enabled=self.is_enabled,
            name=self.name,
            settings=self.settings,
            status=self.status,
            type=self.type)


def get_security_events_provider(id: Optional[_builtins.str] = None,
                                 settings: Optional[Union['GetSecurityEventsProviderSettingsArgs', 'GetSecurityEventsProviderSettingsArgsDict']] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityEventsProviderResult:
    """
    Get information about a Security Events Provider instance for signal ingestion.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_security_events_provider(id="<security_events_provider_id>")
    ```


    :param _builtins.str id: The unique identifier of this instance.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['settings'] = settings
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getSecurityEventsProvider:getSecurityEventsProvider', __args__, opts=opts, typ=GetSecurityEventsProviderResult).value

    return AwaitableGetSecurityEventsProviderResult(
        id=pulumi.get(__ret__, 'id'),
        is_enabled=pulumi.get(__ret__, 'is_enabled'),
        name=pulumi.get(__ret__, 'name'),
        settings=pulumi.get(__ret__, 'settings'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_security_events_provider_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                        settings: Optional[pulumi.Input[Optional[Union['GetSecurityEventsProviderSettingsArgs', 'GetSecurityEventsProviderSettingsArgsDict']]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecurityEventsProviderResult]:
    """
    Get information about a Security Events Provider instance for signal ingestion.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_security_events_provider(id="<security_events_provider_id>")
    ```


    :param _builtins.str id: The unique identifier of this instance.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['settings'] = settings
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getSecurityEventsProvider:getSecurityEventsProvider', __args__, opts=opts, typ=GetSecurityEventsProviderResult)
    return __ret__.apply(lambda __response__: GetSecurityEventsProviderResult(
        id=pulumi.get(__response__, 'id'),
        is_enabled=pulumi.get(__response__, 'is_enabled'),
        name=pulumi.get(__response__, 'name'),
        settings=pulumi.get(__response__, 'settings'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))
