# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecurityEventsProviderArgs', 'SecurityEventsProvider']

@pulumi.input_type
class SecurityEventsProviderArgs:
    def __init__(__self__, *,
                 is_enabled: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']] = None):
        """
        The set of arguments for constructing a SecurityEventsProvider resource.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input['SecurityEventsProviderSettingsArgs'] settings: Information about the Security Events Provider for signal ingestion.
        """
        pulumi.set(__self__, "is_enabled", is_enabled)
        pulumi.set(__self__, "type", type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Input[_builtins.str]:
        """
        Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]:
        """
        Information about the Security Events Provider for signal ingestion.
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]):
        pulumi.set(self, "settings", value)


@pulumi.input_type
class _SecurityEventsProviderState:
    def __init__(__self__, *,
                 is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SecurityEventsProvider resources.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input['SecurityEventsProviderSettingsArgs'] settings: Information about the Security Events Provider for signal ingestion.
        :param pulumi.Input[_builtins.str] status: Indicates whether the Security Events Provider is active or not.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        """
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]:
        """
        Information about the Security Events Provider for signal ingestion.
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]):
        pulumi.set(self, "settings", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Indicates whether the Security Events Provider is active or not.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/securityEventsProvider:SecurityEventsProvider")
class SecurityEventsProvider(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Security Events Provider instances for signal ingestion.

        ## Example Usage

        ### Security Events Provider with Well-Known URL

        ```python
        import pulumi
        import pulumi_okta as okta

        example_wellknown = okta.SecurityEventsProvider("example_wellknown",
            name="Security Events Provider with well-known URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "well_known_url": "https://example.com/.well-known/ssf_configuration",
            })
        ```

        ### Security Events Provider with Issuer and JWKS

        ```python
        import pulumi
        import pulumi_okta as okta

        example_issuer = okta.SecurityEventsProvider("example_issuer",
            name="Security Events Provider with an issuer and a JWKS URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "issuer": "Issuer",
                "jwks_url": "https://example.okta.com/jwks/path",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/securityEventsProvider:SecurityEventsProvider example <security_events_provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']] settings: Information about the Security Events Provider for signal ingestion.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecurityEventsProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Security Events Provider instances for signal ingestion.

        ## Example Usage

        ### Security Events Provider with Well-Known URL

        ```python
        import pulumi
        import pulumi_okta as okta

        example_wellknown = okta.SecurityEventsProvider("example_wellknown",
            name="Security Events Provider with well-known URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "well_known_url": "https://example.com/.well-known/ssf_configuration",
            })
        ```

        ### Security Events Provider with Issuer and JWKS

        ```python
        import pulumi
        import pulumi_okta as okta

        example_issuer = okta.SecurityEventsProvider("example_issuer",
            name="Security Events Provider with an issuer and a JWKS URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "issuer": "Issuer",
                "jwks_url": "https://example.okta.com/jwks/path",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/securityEventsProvider:SecurityEventsProvider example <security_events_provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param SecurityEventsProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityEventsProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityEventsProviderArgs.__new__(SecurityEventsProviderArgs)

            if is_enabled is None and not opts.urn:
                raise TypeError("Missing required property 'is_enabled'")
            __props__.__dict__["is_enabled"] = is_enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["settings"] = settings
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["status"] = None
        super(SecurityEventsProvider, __self__).__init__(
            'okta:index/securityEventsProvider:SecurityEventsProvider',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            settings: Optional[pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'SecurityEventsProvider':
        """
        Get an existing SecurityEventsProvider resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']] settings: Information about the Security Events Provider for signal ingestion.
        :param pulumi.Input[_builtins.str] status: Indicates whether the Security Events Provider is active or not.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityEventsProviderState.__new__(_SecurityEventsProviderState)

        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["settings"] = settings
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return SecurityEventsProvider(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[_builtins.str]:
        """
        Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> pulumi.Output[Optional['outputs.SecurityEventsProviderSettings']]:
        """
        Information about the Security Events Provider for signal ingestion.
        """
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Indicates whether the Security Events Provider is active or not.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")

