# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UiSchemaArgs', 'UiSchema']

@pulumi.input_type
class UiSchemaArgs:
    def __init__(__self__, *,
                 ui_schema: Optional[pulumi.Input['UiSchemaUiSchemaArgs']] = None):
        """
        The set of arguments for constructing a UiSchema resource.
        :param pulumi.Input['UiSchemaUiSchemaArgs'] ui_schema: Properties of the UI schema.
        """
        if ui_schema is not None:
            pulumi.set(__self__, "ui_schema", ui_schema)

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> Optional[pulumi.Input['UiSchemaUiSchemaArgs']]:
        """
        Properties of the UI schema.
        """
        return pulumi.get(self, "ui_schema")

    @ui_schema.setter
    def ui_schema(self, value: Optional[pulumi.Input['UiSchemaUiSchemaArgs']]):
        pulumi.set(self, "ui_schema", value)


@pulumi.input_type
class _UiSchemaState:
    def __init__(__self__, *,
                 ui_schema: Optional[pulumi.Input['UiSchemaUiSchemaArgs']] = None):
        """
        Input properties used for looking up and filtering UiSchema resources.
        :param pulumi.Input['UiSchemaUiSchemaArgs'] ui_schema: Properties of the UI schema.
        """
        if ui_schema is not None:
            pulumi.set(__self__, "ui_schema", ui_schema)

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> Optional[pulumi.Input['UiSchemaUiSchemaArgs']]:
        """
        Properties of the UI schema.
        """
        return pulumi.get(self, "ui_schema")

    @ui_schema.setter
    def ui_schema(self, value: Optional[pulumi.Input['UiSchemaUiSchemaArgs']]):
        pulumi.set(self, "ui_schema", value)


@pulumi.type_token("okta:index/uiSchema:UiSchema")
class UiSchema(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ui_schema: Optional[pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']]] = None,
                 __props__=None):
        """
        Manages UI Schema. This resource allows you to create and configure an Okta [UI Schema](https://developer.okta.com/docs/api/openapi/okta-management/management/tag/UISchema/#tag/UISchema) for form layouts and controls.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.UiSchema("example", ui_schema={
            "button_label": "submit",
            "type": "Group",
            "elements": [{
                "scope": "#/properties/lastName",
            }],
        })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/uiSchema:UiSchema example <ui_schema_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']] ui_schema: Properties of the UI schema.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UiSchemaArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages UI Schema. This resource allows you to create and configure an Okta [UI Schema](https://developer.okta.com/docs/api/openapi/okta-management/management/tag/UISchema/#tag/UISchema) for form layouts and controls.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.UiSchema("example", ui_schema={
            "button_label": "submit",
            "type": "Group",
            "elements": [{
                "scope": "#/properties/lastName",
            }],
        })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/uiSchema:UiSchema example <ui_schema_id>
        ```

        :param str resource_name: The name of the resource.
        :param UiSchemaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UiSchemaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ui_schema: Optional[pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UiSchemaArgs.__new__(UiSchemaArgs)

            __props__.__dict__["ui_schema"] = ui_schema
        super(UiSchema, __self__).__init__(
            'okta:index/uiSchema:UiSchema',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ui_schema: Optional[pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']]] = None) -> 'UiSchema':
        """
        Get an existing UiSchema resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['UiSchemaUiSchemaArgs', 'UiSchemaUiSchemaArgsDict']] ui_schema: Properties of the UI schema.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UiSchemaState.__new__(_UiSchemaState)

        __props__.__dict__["ui_schema"] = ui_schema
        return UiSchema(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="uiSchema")
    def ui_schema(self) -> pulumi.Output[Optional['outputs.UiSchemaUiSchema']]:
        """
        Properties of the UI schema.
        """
        return pulumi.get(self, "ui_schema")

