# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FeaturesArgs', 'Features']

@pulumi.input_type
class FeaturesArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 capabilities: Optional[pulumi.Input['FeaturesCapabilitiesArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Features resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to configure features for.
        :param pulumi.Input['FeaturesCapabilitiesArgs'] capabilities: Configuration block for feature capabilities. See Capabilities below.
        :param pulumi.Input[_builtins.str] description: Description of the feature.
        :param pulumi.Input[_builtins.str] name: The name of the feature to configure. Valid values:
               * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
               * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
        :param pulumi.Input[_builtins.str] status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        pulumi.set(__self__, "app_id", app_id)
        if capabilities is not None:
            pulumi.set(__self__, "capabilities", capabilities)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the application to configure features for.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def capabilities(self) -> Optional[pulumi.Input['FeaturesCapabilitiesArgs']]:
        """
        Configuration block for feature capabilities. See Capabilities below.
        """
        return pulumi.get(self, "capabilities")

    @capabilities.setter
    def capabilities(self, value: Optional[pulumi.Input['FeaturesCapabilitiesArgs']]):
        pulumi.set(self, "capabilities", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the feature.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the feature to configure. Valid values:
        * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
        * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _FeaturesState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 capabilities: Optional[pulumi.Input['FeaturesCapabilitiesArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Features resources.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to configure features for.
        :param pulumi.Input['FeaturesCapabilitiesArgs'] capabilities: Configuration block for feature capabilities. See Capabilities below.
        :param pulumi.Input[_builtins.str] description: Description of the feature.
        :param pulumi.Input[_builtins.str] name: The name of the feature to configure. Valid values:
               * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
               * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
        :param pulumi.Input[_builtins.str] status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if capabilities is not None:
            pulumi.set(__self__, "capabilities", capabilities)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the application to configure features for.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def capabilities(self) -> Optional[pulumi.Input['FeaturesCapabilitiesArgs']]:
        """
        Configuration block for feature capabilities. See Capabilities below.
        """
        return pulumi.get(self, "capabilities")

    @capabilities.setter
    def capabilities(self, value: Optional[pulumi.Input['FeaturesCapabilitiesArgs']]):
        pulumi.set(self, "capabilities", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the feature.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the feature to configure. Valid values:
        * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
        * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:app/features:Features")
class Features(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 capabilities: Optional[pulumi.Input[Union['FeaturesCapabilitiesArgs', 'FeaturesCapabilitiesArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        App features can be imported using the format `{app_id}/{feature_name}`:

        bash

        ```sh
        $ pulumi import okta:app/features:Features example 0oarblaf7hWdLawNg1d7/USER_PROVISIONING
        ```

        bash

        ```sh
        $ pulumi import okta:app/features:Features inbound 0oarblaf7hWdLawNg1d7/INBOUND_PROVISIONING
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to configure features for.
        :param pulumi.Input[Union['FeaturesCapabilitiesArgs', 'FeaturesCapabilitiesArgsDict']] capabilities: Configuration block for feature capabilities. See Capabilities below.
        :param pulumi.Input[_builtins.str] description: Description of the feature.
        :param pulumi.Input[_builtins.str] name: The name of the feature to configure. Valid values:
               * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
               * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
        :param pulumi.Input[_builtins.str] status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FeaturesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        App features can be imported using the format `{app_id}/{feature_name}`:

        bash

        ```sh
        $ pulumi import okta:app/features:Features example 0oarblaf7hWdLawNg1d7/USER_PROVISIONING
        ```

        bash

        ```sh
        $ pulumi import okta:app/features:Features inbound 0oarblaf7hWdLawNg1d7/INBOUND_PROVISIONING
        ```

        :param str resource_name: The name of the resource.
        :param FeaturesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FeaturesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 capabilities: Optional[pulumi.Input[Union['FeaturesCapabilitiesArgs', 'FeaturesCapabilitiesArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FeaturesArgs.__new__(FeaturesArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["capabilities"] = capabilities
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["status"] = status
        super(Features, __self__).__init__(
            'okta:app/features:Features',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            capabilities: Optional[pulumi.Input[Union['FeaturesCapabilitiesArgs', 'FeaturesCapabilitiesArgsDict']]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'Features':
        """
        Get an existing Features resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to configure features for.
        :param pulumi.Input[Union['FeaturesCapabilitiesArgs', 'FeaturesCapabilitiesArgsDict']] capabilities: Configuration block for feature capabilities. See Capabilities below.
        :param pulumi.Input[_builtins.str] description: Description of the feature.
        :param pulumi.Input[_builtins.str] name: The name of the feature to configure. Valid values:
               * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
               * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
        :param pulumi.Input[_builtins.str] status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FeaturesState.__new__(_FeaturesState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["capabilities"] = capabilities
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["status"] = status
        return Features(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the application to configure features for.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def capabilities(self) -> pulumi.Output[Optional['outputs.FeaturesCapabilities']]:
        """
        Configuration block for feature capabilities. See Capabilities below.
        """
        return pulumi.get(self, "capabilities")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the feature.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the feature to configure. Valid values:
        * `USER_PROVISIONING` - User profiles are pushed from Okta to the third-party app.
        * `INBOUND_PROVISIONING` - User profiles are imported from the third-party app into Okta.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")

