# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApiServiceIntegrationArgs', 'ApiServiceIntegration']

@pulumi.input_type
class ApiServiceIntegrationArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]] = None):
        """
        The set of arguments for constructing a ApiServiceIntegration resource.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        :param pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        """
        pulumi.set(__self__, "type", type)
        if granted_scopes is not None:
            pulumi.set(__self__, "granted_scopes", granted_scopes)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="grantedScopes")
    def granted_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]:
        """
        The list of Okta management scopes granted to the API Service Integration instance.
        """
        return pulumi.get(self, "granted_scopes")

    @granted_scopes.setter
    def granted_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]):
        pulumi.set(self, "granted_scopes", value)


@pulumi.input_type
class _ApiServiceIntegrationState:
    def __init__(__self__, *,
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApiServiceIntegration resources.
        :param pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        :param pulumi.Input[_builtins.str] name: The name of the API service integration that corresponds with the type property.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        if granted_scopes is not None:
            pulumi.set(__self__, "granted_scopes", granted_scopes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="grantedScopes")
    def granted_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]:
        """
        The list of Okta management scopes granted to the API Service Integration instance.
        """
        return pulumi.get(self, "granted_scopes")

    @granted_scopes.setter
    def granted_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]):
        pulumi.set(self, "granted_scopes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API service integration that corresponds with the type property.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/apiServiceIntegration:ApiServiceIntegration")
class ApiServiceIntegration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## ---

        page_title: "Resource: ApiServiceIntegration"
        description: |-

        ***

        # Resource: ApiServiceIntegration

        This API provides operations to manage API service integration instances in your org.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiServiceIntegration("example",
            type="anzennaapiservice",
            granted_scopes=[
                {
                    "scope": "okta.users.read",
                },
                {
                    "scope": "okta.groups.read",
                },
                {
                    "scope": "okta.logs.read",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/apiServiceIntegration:ApiServiceIntegration example <api_service_integration_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiServiceIntegrationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## ---

        page_title: "Resource: ApiServiceIntegration"
        description: |-

        ***

        # Resource: ApiServiceIntegration

        This API provides operations to manage API service integration instances in your org.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiServiceIntegration("example",
            type="anzennaapiservice",
            granted_scopes=[
                {
                    "scope": "okta.users.read",
                },
                {
                    "scope": "okta.groups.read",
                },
                {
                    "scope": "okta.logs.read",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/apiServiceIntegration:ApiServiceIntegration example <api_service_integration_id>
        ```

        :param str resource_name: The name of the resource.
        :param ApiServiceIntegrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiServiceIntegrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiServiceIntegrationArgs.__new__(ApiServiceIntegrationArgs)

            __props__.__dict__["granted_scopes"] = granted_scopes
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["name"] = None
        super(ApiServiceIntegration, __self__).__init__(
            'okta:index/apiServiceIntegration:ApiServiceIntegration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApiServiceIntegration':
        """
        Get an existing ApiServiceIntegration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        :param pulumi.Input[_builtins.str] name: The name of the API service integration that corresponds with the type property.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiServiceIntegrationState.__new__(_ApiServiceIntegrationState)

        __props__.__dict__["granted_scopes"] = granted_scopes
        __props__.__dict__["name"] = name
        __props__.__dict__["type"] = type
        return ApiServiceIntegration(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="grantedScopes")
    def granted_scopes(self) -> pulumi.Output[Optional[Sequence['outputs.ApiServiceIntegrationGrantedScope']]]:
        """
        The list of Okta management scopes granted to the API Service Integration instance.
        """
        return pulumi.get(self, "granted_scopes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the API service integration that corresponds with the type property.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        return pulumi.get(self, "type")

